from setuptools import setup

setup(name='gaussian_binomial_dist',
      version='0.1.1',
      description='Gaussian and Binomial distributions',
      packages=['gaussian_binomial_dist'],
      author= 'Bogdan Balcau',
      zip_safe=False)
